# Chocolatey

This folder contains everything necessary to build and publish the chocolatey package.

The icon is not included in the package, but instead it is served through a static CDN and its url is in the iconUrl tag in the .nuspec.

The CDN used is [statically](https://statically.io/docs/using-staticzap/).
